@@ -1,12 +1,14 @@
 package FabForce::DBDesigner4;
 
+# ABSTRACT:  Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
+
 use strict;
 use warnings;
 use Carp;
 use FabForce::DBDesigner4::XML;
 use FabForce::DBDesigner4::SQL;
 
-our $VERSION     = '0.31';
+our $VERSION     = '0.32';
 
 sub new{
   my ($class,%args) = @_;
@@ -68,11 +70,11 @@ sub getSQL{
 
 =head1 NAME
 
-FabForce::DBDesigner4
+FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -91,10 +93,6 @@ FabForce (http://www.fabforce.net).
 B<NOTICE>: As of version 0.2 you can not parse sql files any longer. You just
 can parse xml files created by DBDesigner. And you can't create XML files!
 
-=head1 NAME
-
-FabForce::DBDesigner4 - Parse/Analyse XML-Files created by DBDesigner 4 (FabForce)
-
 =head1 METHODS
 
 =head2 new
@@ -218,19 +216,6 @@ bugreports or comments on this module.
 
 =head1 AUTHOR
 
-Renee Baecker, E<lt>module@renee-baecker.deE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2005 - 2011 by Renee Baecker
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the Artistic License version 2.0.
-
-These conditions apply for all files in this package.
-
-=head1 AUTHOR
-
 Renee Baecker <module@renee-baecker.de>
 
 =head1 COPYRIGHT AND LICENSE
@@ -239,7 +224,7 @@ This software is Copyright (c) 2010 by Renee Baecker.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
